@@ -1,23 +1,23 @@
+'''Module that implements the kraken Spot websocket clients'''
+import sys
+import logging
 import json
 import time
 import asyncio
-import websockets
 from random import random
-from uuid import uuid4
-import logging
 import traceback
 import copy
-import sys 
 from typing import List
+import websockets
 
 try:
     from kraken.spot.ws_client.ws_client import SpotWsClientCl
-    from kraken.exceptions.exceptions import KrakenExceptions 
+    from kraken.exceptions.exceptions import KrakenExceptions
 except ModuleNotFoundError:
     print('USING LOCAL MODULE')
     sys.path.append('/Users/benjamin/repositories/Trading/python-kraken-sdk')
     from kraken.spot.client.ws_client import SpotWsClientCl
-    from kraken.exceptions.exceptions import KrakenExceptions 
+    from kraken.exceptions.exceptions import KrakenExceptions
 
 class ConnectSpotWebsocket:
     '''
@@ -39,41 +39,43 @@ class ConnectSpotWebsocket:
 
     MAX_RECONNECT_NUM = 10
 
-    def __init__(self, client, endpoint: str, callback, isAuth: bool=False):
+    def __init__(self, client, endpoint: str, callback, is_auth: bool=False):
         self.__client = client
         self.__ws_endpoint = endpoint
-        self.__callback = callback 
+        self.__callback = callback
 
         self.__reconnect_num = 0
         self.__ws_conn_details = None
 
-        self.__isAuth = isAuth
+        self.__is_auth = is_auth
 
         self.__last_ping = None
         self.__socket = None
         self.__subscriptions = []
 
-        self.__task = asyncio.ensure_future(
+        asyncio.ensure_future(
             self.__run_forever(),
             loop=asyncio.get_running_loop()
         )
 
     @property
     def subscriptions(self) -> list:
+        '''Returns the active subscriptions'''
         return self.__subscriptions
 
     @property
-    def isAuth(self) -> bool:
-        return self.__isAuth
+    def is_auth(self) -> bool:
+        '''Returns true if the connection can access privat endpoints'''
+        return self.__is_auth
 
     async def __run(self, event: asyncio.Event):
         keep_alive = True
         self.__last_ping = time.time()
-        self.__ws_conn_details = None if not self.__isAuth else self.__client.get_ws_token()
+        self.__ws_conn_details = None if not self.__is_auth else self.__client.get_ws_token()
         logging.debug(f'Websocket token: {self.__ws_conn_details}')
 
         async with websockets.connect(f'wss://{self.__ws_endpoint}', ping_interval=None) as socket:
-            logging.info(f'Websocket connected!')
+            logging.info('Websocket connected!')
             self.__socket = socket
 
             if not event.is_set():
@@ -85,8 +87,8 @@ class ConnectSpotWebsocket:
                 if time.time() - self.__last_ping > 10: await self.send_ping()
                 try:
                     _msg = await asyncio.wait_for(self.__socket.recv(), timeout=15)
-                except asyncio.TimeoutError:
-                    await self.send_ping()
+                except asyncio.TimeoutError: # important
+                    await self.send_ping() 
                 except asyncio.CancelledError:
                     logging.exception('asyncio.CancelledError')
                     keep_alive = False
@@ -94,26 +96,26 @@ class ConnectSpotWebsocket:
                 else:
                     try: msg = json.loads(_msg)
                     except ValueError: logging.warning(_msg)
-                    else: 
+                    else:
                         if 'event' in msg:
                             if msg['event'] == 'subscriptionStatus' and 'status' in msg:
                                 # remove/assign un/subscriptions
                                 try:
                                     if msg['status'] == 'subscribed':
-                                        self.__append_subscription(msg)    
-                                    elif msg['status'] == 'unsubscribed': 
-                                        self.__remove_subscription(msg)  
-                                    elif msg['status'] == 'error': logging.warn(msg)
+                                        self.__append_subscription(msg)
+                                    elif msg['status'] == 'unsubscribed':
+                                        self.__remove_subscription(msg)
+                                    elif msg['status'] == 'error': logging.warning(msg)
                                 except AttributeError: pass
                         await self.__callback(msg)
 
     async def __run_forever(self) -> None:
         try:
             while True: await self.__reconnect()
-        except KrakenExceptions.MaxReconnectError: 
+        except KrakenExceptions.MaxReconnectError:
             await self.__callback({'error': 'kraken.exceptions.exceptions.KrakenExceptions.MaxReconnectError'})
-        except Exception as e:
-            logging.error(f'{e}: {traceback.format_exc()}')
+        except Exception as execption:
+            logging.error(f'{execption}: {traceback.format_exc()}')
         finally: self.__client.exception_occur = True
 
     async def __reconnect(self):
@@ -124,9 +126,11 @@ class ConnectSpotWebsocket:
             raise KrakenExceptions.MaxReconnectError()
 
         reconnect_wait = self.__get_reconnect_wait(self.__reconnect_num)
-        logging.debug(f'asyncio sleep reconnect_wait={reconnect_wait} s reconnect_num={self.__reconnect_num}')
+        logging.debug(
+            f'asyncio sleep reconnect_wait={reconnect_wait} s reconnect_num={self.__reconnect_num}'
+        )
         await asyncio.sleep(reconnect_wait)
-        logging.debug(f'asyncio sleep done')
+        logging.debug('asyncio sleep done')
         event = asyncio.Event()
 
         tasks = {
@@ -152,7 +156,9 @@ class ConnectSpotWebsocket:
         logging.warning('reconnect over')
 
     async def __recover_subscriptions(self, event):
-        logging.info(f'Recover {"auth" if self.__isAuth else "public"} subscriptions {self.__subscriptions} waiting.')
+        logging.info(
+            f'Recover {"auth" if self.__is_auth else "public"} subscriptions {self.__subscriptions} waiting.'
+        )
         await event.wait()
 
         for sub in self.__subscriptions:
@@ -162,13 +168,16 @@ class ConnectSpotWebsocket:
                 and 'name' in sub['subscription']   \
                 and sub['subscription']['name'] in self.__client.private_sub_names:
                 cpy['subscription']['token'] = self.__ws_conn_details['token']
-                private = True            
+                private = True
             await self.send_message(cpy, private=private)
             logging.info(f'{sub} OK')
 
-        logging.info(f'Recovering {"auth" if self.__isAuth else "public"} subscriptions {self.__subscriptions} done.')
+        logging.info(
+            f'Recovering {"auth" if self.__is_auth else "public"} subscriptions {self.__subscriptions} done.'
+        )
 
     async def send_ping(self):
+        '''Sends ping to Keaken'''
         msg = {
             'event': 'ping',
             'reqid': int(time.time() * 1000),
@@ -176,22 +185,23 @@ class ConnectSpotWebsocket:
         await self.__socket.send(json.dumps(msg))
         self.__last_ping = time.time()
 
-    async def send_message(self, msg, private: bool=False, retry_count: int=0):
+    async def send_message(self, msg, private: bool=False):
+        '''Sends a message via websocket'''
         while not self.__socket: await asyncio.sleep(.4)
 
-        if private and not self.__isAuth:
+        if private and not self.__is_auth:
             raise ValueError('Cannot send private message with public websocket.')
-        else:
-            msg['reqid'] = int(time.time() * 1000)
-            if private and 'subscription' in msg: msg['subscription']['token'] = self.__ws_conn_details['token']
-            elif private: msg['token'] = self.__ws_conn_details['token']
-            await self.__socket.send(json.dumps(msg))
+
+        msg['reqid'] = int(time.time() * 1000)
+        if private and 'subscription' in msg: msg['subscription']['token'] = self.__ws_conn_details['token']
+        elif private: msg['token'] = self.__ws_conn_details['token']
+        await self.__socket.send(json.dumps(msg))
 
     def __append_subscription(self, msg: dict) -> None:
         ''' Add a dictionary containing subscription information to list
-            This is used to recover when the connection gets interrupted.       
+            This is used to recover when the connection gets interrupted.
 
-            This function should only be called in 
+            This function should only be called in
             when self.__run receives a msg and the following conditions met:
                 'event' in msg                           \
                 and msg['event'] == 'subscriptionStatus' \
@@ -200,15 +210,15 @@ class ConnectSpotWebsocket:
 
             ====== P A R A M E T E R S ======
             msg: dict
-                must be like: { 'subscription': { 'name': '<placeholder>', 'placeholder': 'placeholder', ... }} 
+                must be like: { 'subscription': { 'name': '<placeholder>', 'placeholder': 'placeholder', ... }}
         '''
-        self.__remove_subscription(msg)# remove from list, to avoid duplicates
+        self.__remove_subscription(msg) # remove from list, to avoid duplicates
         self.__subscriptions.append(self.__build_subscription(msg))
 
     def __remove_subscription(self, msg: dict) -> None:
         ''' Remove a dictionary containing subscription information from list.
 
-            This function should only be called in 
+            This function should only be called in
             when self.__run receives a msg and the following conditions met:
                 'event' in msg                           \
                 and msg['event'] == 'subscriptionStatus' \
@@ -217,7 +227,7 @@ class ConnectSpotWebsocket:
 
             ====== P A R A M E T E R S ======
             msg: dict
-                must be like: { 'subscription': { 'name': '<placeholder>', 'placeholder': 'placeholder', ... }} 
+                must be like: { 'subscription': { 'name': '<placeholder>', 'placeholder': 'placeholder', ... }}
         '''
         sub = self.__build_subscription(msg)
         self.__subscriptions = [x for x in self.__subscriptions if x != sub]
@@ -225,15 +235,15 @@ class ConnectSpotWebsocket:
     def __build_subscription(self, msg: dict) -> dict:
         sub = { 'event': 'subscribe' }
 
-        if not 'subscription' in msg or 'name' not in msg['subscription']: 
+        if not 'subscription' in msg or 'name' not in msg['subscription']:
             raise ValueError('Cannot remove subscription with missing attributes.')
-        elif msg['subscription']['name'] in self.__client.public_sub_names: # public endpoint
-            if 'pair' in msg: 
-                sub['pair'] = msg['pair'] if type(msg['pair']) == list else [msg['pair']]
+        if msg['subscription']['name'] in self.__client.public_sub_names: # public endpoint
+            if 'pair' in msg:
+                sub['pair'] = msg['pair'] if isinstance(msg['pair'], list) else [msg['pair']]
             sub['subscription'] = msg['subscription']
         elif msg['subscription']['name'] in self.__client.private_sub_names: # private endpoint
             sub['subscription'] = { 'name': msg['subscription']['name'] }
-        else: logging.warn('Feed not implemented. Please contact the python-kraken-sdk package author.')
+        else: logging.warning('Feed not implemented. Please contact the python-kraken-sdk package author.')
         return sub
 
     def __get_reconnect_wait(self, attempts: int) -> float:
@@ -241,12 +251,12 @@ class ConnectSpotWebsocket:
 
 class KrakenSpotWSClientCl(SpotWsClientCl):
     '''https://docs.kraken.com/websockets/#overview
-    
-        Class to access public and (optional) 
+
+        Class to access public and (optional)
         private/authenticated websocket connection.
 
         This class holds up to two websocket connections, one private
-        and one public. 
+        and one public.
 
         ====== P A R A M E T E R S ======
         key: str, [optional], default: ''
@@ -279,10 +289,10 @@ class KrakenSpotWSClientCl(SpotWsClientCl):
 
                 async def on_message(self, event) -> None:
                     print(event)
-            
+
             bot = Bot() # unauthenticated
             auth_bot = Bot(key='kraken-api-key', secret='kraken-secret-key') # authenticated
-            
+
             # ... now call for example subscribe and so on
 
             while True: await asyncio.sleep(6)
@@ -302,27 +312,27 @@ class KrakenSpotWSClientCl(SpotWsClientCl):
     def __init__(self, key: str='', secret: str='', url: str='', callback=None, beta: bool=False):
         super().__init__(key=key, secret=secret, url=url, sandbox=beta)
         self.__callback = callback
-        self.__isAuth = key and secret        
-        
+        self.__is_auth = key and secret
+
         self.exception_occur = False
         self._pub_conn = ConnectSpotWebsocket(
             client=self,
             endpoint=self.PROD_ENV_URL if not beta else self.BETA_ENV_URL,
-            isAuth=False,
+            is_auth=False,
             callback=self.on_message
         )
 
         self._priv_conn = ConnectSpotWebsocket(
              client=self,
              endpoint=self.AUTH_PROD_ENV_URL if not beta else self.AUTH_BETA_ENV_URL,
-             isAuth=True,
+             is_auth=True,
              callback=self.on_message
-        ) if self.__isAuth else None
+        ) if self.__is_auth else None
 
     async def on_message(self, msg: dict):
-        ''' Calls the defined callback function (if defined) 
+        ''' Calls the defined callback function (if defined)
             or overload this function
-            
+
             ====== P A R A M E T E R S ======
             msg: dict
                 message received from Kraken via the websocket connection
@@ -330,7 +340,7 @@ class KrakenSpotWSClientCl(SpotWsClientCl):
             ====== N O T E S ======
             Can be overloaded like in the documentation of this class.
         '''
-        if self.__callback != None: await self.__callback(msg)
+        if self.__callback is not None: await self.__callback(msg)
         else:
             logging.warning('Received event but no callback is defined')
             print(msg)
@@ -338,7 +348,7 @@ class KrakenSpotWSClientCl(SpotWsClientCl):
     async def subscribe(self, subscription: dict, pair: List[str]=None) -> None:
         '''Subscribe to a channel
             https://docs.kraken.com/websockets-beta/#message-subscribe
-            
+
             ====== P A R A M E T E R S ======
             subscription: dict
                 the subscription to subscribe to
@@ -349,31 +359,31 @@ class KrakenSpotWSClientCl(SpotWsClientCl):
             # ... initialize bot as documented on top of this class.
             await bot.subscribe(subscription={"name": ticker}, pair=["XBTUSD", "DOT/EUR"])
 
-            ====== N O T E S ====== 
-            Success or failures are sent over the websocket connection and can be  
+            ====== N O T E S ======
+            Success or failures are sent over the websocket connection and can be
             received via the on_message callback function.
         '''
 
         if 'name' not in subscription: raise AttributeError('Subscription requires a "name" key."')
-        private = True if subscription['name'] in self.private_sub_names else False
+        private = bool(subscription['name'] in self.private_sub_names)
 
-        payload = { 
+        payload = {
             'event': 'subscribe',
             'subscription': subscription
         }
-        if pair != None: 
-            if type(pair) != list: raise ValueError('Parameter pair must be type of List[str] (e.g. pair=["XBTUSD"])')
-            else: payload['pair'] = pair        
+        if pair is not None:
+            if not isinstance(pair, list): raise ValueError('Parameter pair must be type of List[str] (e.g. pair=["XBTUSD"])')
+            payload['pair'] = pair
 
         if private: # private == without pair
-            if not self.__isAuth: raise ValueError('Cannot subscribe to private feeds without valid credentials!')
-            elif pair != None: raise ValueError('Cannot subscribe to private endpoint with specific pair!')
-            else: await self._priv_conn.send_message(payload, private=True)
+            if not self.__is_auth: raise ValueError('Cannot subscribe to private feeds without valid credentials!')
+            if pair is not None: raise ValueError('Cannot subscribe to private endpoint with specific pair!')
+            await self._priv_conn.send_message(payload, private=True)
 
-        elif pair != None: # public with pair
-            for p in pair:
+        elif pair is not None: # public with pair
+            for symbol in pair:
                 sub = copy.deepcopy(payload)
-                sub['pair'] = [p]
+                sub['pair'] = [symbol]
                 await self._pub_conn.send_message(sub, private=False)
 
         else: await self._pub_conn.send_message(payload, private=False)
@@ -392,52 +402,56 @@ class KrakenSpotWSClientCl(SpotWsClientCl):
             # ... initialize bot as documented on top of this class.
             bot.unsubscribe(subscription={"name": ticker}, pair=["XBTUSD", "DOT/EUR"])
 
-            ====== N O T E S ====== 
-            Success or failures are sent over the websocket connection and can be  
+            ====== N O T E S ======
+            Success or failures are sent over the websocket connection and can be
             received via the on_message callback function.
         '''
         if 'name' not in subscription: raise AttributeError('Subscription requires a "name" key."')
-        private = True if subscription['name'] in self.private_sub_names else False
+        private = bool(subscription['name'] in self.private_sub_names)
 
-        payload = { 
+        payload = {
             'event': 'unsubscribe',
             'subscription': subscription
         }
-        if pair != None: 
-            if type(pair) != list: raise ValueError('Parameter pair must be type of List[str] (e.g. pair=["XBTUSD"])')
-            else: payload['pair'] = pair
-        
+        if pair is not None:
+            if not isinstance(pair, list): raise ValueError('Parameter pair must be type of List[str] (e.g. pair=["XBTUSD"])')
+            payload['pair'] = pair
+
         if private: # private == without pair
-            if not self.__isAuth: raise ValueError('Cannot unsubscribe from private feeds without valid credentials!')
-            elif pair != None: raise ValueError('Cannot unsubscribe from private endpoint with specific pair!')
-            else: await self._priv_conn.send_message(payload, private=True)
-                
-        elif pair != None: # public with pair
-            for p in pair:
+            if not self.__is_auth: raise ValueError('Cannot unsubscribe from private feeds without valid credentials!')
+            if pair is not None: raise ValueError('Cannot unsubscribe from private endpoint with specific pair!')
+            await self._priv_conn.send_message(payload, private=True)
+
+        elif pair is not None: # public with pair
+            for symbol in pair:
                 sub = copy.deepcopy(payload)
-                sub['pair'] = [p]
+                sub['pair'] = [symbol]
                 await self._pub_conn.send_message(sub, private=False)
-                               
+
         else: await self._pub_conn.send_message(payload, private=False)
 
     @property
     def private_sub_names(self) -> List[str]:
+        '''Returns the private subscription names'''
         return  ['ownTrades', 'openOrders']
 
     @property
     def public_sub_names(self) -> List[str]:
+        '''Returns the public subscription names'''
         return ['ticker', 'spread', 'book', 'ohlc', 'trade', '*']
 
     @property
     def active_public_subscriptions(self) -> List[str]:
-        if self._pub_conn != None:
-            return self._pub_conn.subscriptions 
-        else: raise ConnectionError('Public connection does not exist!')
+        '''Returns the active public subscriptions'''
+        if self._pub_conn is not None:
+            return self._pub_conn.subscriptions
+        raise ConnectionError('Public connection does not exist!')
 
     @property
     def active_private_subscriptions(self) -> List[str]:
-        if self._priv_conn != None:
+        '''Returns the active private subscriptions'''
+        if self._priv_conn is not None:
             return self._priv_conn.subscriptions
-        else: raise ConnectionError('Private connection does not exist!')
+        raise ConnectionError('Private connection does not exist!')
 
 
